import gulp from "gulp";
import sass from "gulp-sass";
import rimraf from "rimraf";
import plumber from "gulp-plumber";
import prettier from "gulp-prettier";
import browserSync from "browser-sync";

const reload = browserSync.reload;

gulp.task("rmrf", () => {
  rimraf.sync("build");
});

gulp.task("css", () => {
  return gulp
    .src([ "_lib/bedrock.scss" ])
    .pipe(plumber())
    .pipe(sass({ outputStyle: "compressed" }))
    .pipe(gulp.dest("dist"))
    .pipe(reload({ stream: true }));
});

gulp.task("js", () => {
  gulp
    .src([ "src/js/styleguide.js" ], { base: "." })
    .pipe(prettier({ useFlowParser: true }))
    .pipe(gulp.dest("."));
});

gulp.task("default", [ "rmrf", "css", "js" ]);

gulp.task("watch", () => {
  gulp.start("default");

  browserSync({ server: { baseDir: "./" }, open: false });

  gulp.watch("_lib/**/*.scss", [ "css" ]);
  gulp.watch("**/*.js", [ "js" ]);
  gulp.watch([ "*.html", "src/**/*.css", "src/**/*.js" ]).on("change", reload);
});
